@@ -292,17 +292,6 @@ class AdminCog(commands.Cog):
         async with AdminAction.create(self.bot, interaction) as action:
             await action.set_delete_expired(setting)
 
-    @set_group.command(
-        name="show_points",
-        description="Set the option for showing points on games in this channel.",
-    )
-    @app_commands.describe(setting="Setting")
-    @tracer.wrap(name="interaction", resource="set_show_points")
-    async def show_points(self, interaction: discord.Interaction, setting: bool) -> None:
-        add_span_context(interaction)
-        async with AdminAction.create(self.bot, interaction) as action:
-            await action.set_show_points(setting)
-
     @set_group.command(
         name="blind_games",
         description="Should player names be hidden in public game posts?",
@@ -314,18 +303,6 @@ class AdminCog(commands.Cog):
         async with AdminAction.create(self.bot, interaction) as action:
             await action.set_blind_games(setting)
 
-    # TODO: I need to completely rework how the ELO system works.
-    # @set_group.command(
-    #     name="require_confirmation",
-    #     description="Set the option for requiring points confirmation on games in this channel.",
-    # )
-    # @app_commands.describe(setting="Setting")
-    # @tracer.wrap(name="interaction", resource="set_require_confirmation")
-    # async def require_confirmation(self, interaction: discord.Interaction, setting: bool) -> None:
-    #     add_span_context(interaction)
-    #     async with AdminAction.create(self.bot, interaction) as action:
-    #         await action.set_require_confirmation(setting)
-
     @set_group.command(
         name="voice_invite",
         description="Set the option for voice invite creation on games in this channel.",
