@@ -269,8 +269,78 @@ class Game(Base):
         plural = "s" if remaining > 1 else ""
         return f"**Waiting for {remaining} more player{plural} to join...**"
 
+    def embed_motd(self) -> list[str]:
+        placeholders = self.placeholders
+        parts: list[str] = []
+        if self.guild.motd:
+            parts.append(f"{self.apply_placeholders(placeholders, self.guild.motd)}")
+        if self.channel.motd:
+            parts.append(f"{self.apply_placeholders(placeholders, self.channel.motd)}")
+        return parts
+
+    def embed_description_link_info(
+        self,
+        effective_service: GameService,
+        dm: bool,
+        rematch: bool,
+    ) -> str:
+        if self.status != GameStatus.STARTED.value:
+            return effective_service.pending_msg
+        if not self.show_links(dm):
+            return "Please check your Direct Messages for your game details."
+        if rematch:
+            return (
+                "This is a rematch of a previous game. "
+                "Please continue using the same game lobby and voice channel."
+            )
+        if self.game_link:
+            return f"# [Join your {effective_service} game now!]({self.game_link})"
+        if effective_service.fallback_url:
+            return (
+                "Sorry but SpellBot was unable to create a link"
+                f" for this game. Please go to [{effective_service}]"
+                f"({effective_service.fallback_url}) to create one."
+            )
+        if effective_service.value != GameService.NOT_ANY.value:
+            return f"Please use {effective_service} to play this game."
+        return "Contact the other players in your game to organize this match."
+
+    def embed_description_extras(
+        self,
+        dm: bool,
+        suggested_vc: VoiceChannelSuggestion | None,
+    ) -> list[str]:
+        if self.status != GameStatus.STARTED.value:
+            return []
+        parts: list[str] = []
+        if self.show_links(dm):
+            if self.password:
+                parts.append(f"Password: `{self.password}`")
+            if self.voice_xid:
+                parts.append(f"## Join your voice chat now: <#{self.voice_xid}>")
+            if self.voice_invite_link:
+                parts.append(f"Or use this voice channel invite: {self.voice_invite_link}")
+            if suggested_vc:
+                if suggested_vc.already_picked is not None:
+                    parts.append(
+                        "## Your pod is already using a voice channel, "
+                        f"join them now: <#{suggested_vc.already_picked}>!\n{HR}"
+                    )
+                elif suggested_vc.random_empty is not None:
+                    parts.append(
+                        "## Please consider using this available voice channel: "
+                        f"<#{suggested_vc.random_empty}>.\n{HR}"
+                    )
+        if dm:
+            jump_link = next(iter(self.jump_links.values()))
+            parts.append(
+                "You can also [jump to the original game post]"
+                f"({jump_link}) in <#{self.channel_xid}>."
+            )
+        return parts
+
     @tracer.wrap()
-    def embed_description(  # noqa: C901, PLR0912
+    def embed_description(
         self,
         *,
         guild: discord.Guild | None,
@@ -288,62 +358,14 @@ class Game(Base):
                 }
             )
 
-        description = ""
-        if self.guild.notice:
-            description += f"{self.guild.notice}\n\n"
         effective_service = GameService(int(self.service))
-        if self.status == GameStatus.PENDING.value:
-            description += effective_service.pending_msg
-        else:
-            if self.show_links(dm):
-                if rematch:
-                    description += (
-                        "This is a rematch of a previous game. "
-                        "Please continue using the same game lobby and voice channel."
-                    )
-                elif self.game_link:
-                    description += f"# [Join your {effective_service} game now!]({self.game_link})"
-                elif effective_service.fallback_url:
-                    description += (
-                        "Sorry but SpellBot was unable to create a link"
-                        f" for this game. Please go to [{effective_service}]"
-                        f"({effective_service.fallback_url}) to create one."
-                    )
-                elif effective_service.value != GameService.NOT_ANY.value:
-                    description += f"Please use {effective_service} to play this game."
-                else:
-                    description += "Contact the other players in your game to organize this match."
-                if self.password:
-                    description += f"\n\nPassword: `{self.password}`"
-                if self.voice_xid:
-                    description += f"\n\n## Join your voice chat now: <#{self.voice_xid}>"
-                if self.voice_invite_link:
-                    description += f"\nOr use this voice channel invite: {self.voice_invite_link}"
-                if suggested_vc:
-                    if suggested_vc.already_picked is not None:
-                        description += (
-                            "\n\n## Your pod is already using a voice channel, "
-                            f"join them now: <#{suggested_vc.already_picked}>!\n{HR}"
-                        )
-                    elif suggested_vc.random_empty is not None:
-                        description += (
-                            "\n\n## Please consider using this available voice channel: "
-                            f"<#{suggested_vc.random_empty}>.\n{HR}"
-                        )
-            else:
-                description += "Please check your Direct Messages for your game details."
-            if dm:
-                jump_link = next(iter(self.jump_links.values()))
-                description += (
-                    "\n\nYou can also [jump to the original game post]"
-                    f"({jump_link}) in <#{self.channel_xid}>."
-                )
-        placeholders = self.placeholders
-        if self.guild.motd:
-            description += f"\n\n{self.apply_placeholders(placeholders, self.guild.motd)}"
-        if self.channel.motd:
-            description += f"\n\n{self.apply_placeholders(placeholders, self.channel.motd)}"
-        return description
+        parts: list[str] = []
+        if self.guild.notice:
+            parts.append(f"{self.guild.notice}")
+        parts.append(self.embed_description_link_info(effective_service, dm, rematch))
+        parts.extend(self.embed_description_extras(dm, suggested_vc))
+        parts.extend(self.embed_motd())
+        return "\n\n".join(parts)
 
     @property
     def placeholders(self) -> dict[str, str]:
@@ -405,7 +427,6 @@ class Game(Base):
         suggested_vc: VoiceChannelSuggestion | None = None,
         rematch: bool = False,
     ) -> discord.Embed:
-        # Basic embed
         title = "**Rematch Game!**" if rematch else self.embed_title
         embed = discord.Embed(title=title)
         embed.set_thumbnail(url=settings.thumb(self.guild_xid))
@@ -415,12 +436,8 @@ class Game(Base):
             suggested_vc=suggested_vc,
             rematch=rematch,
         )
-
-        # Rules
         if self.rules:
             embed.add_field(name="⚠️ Additional Rules:", value=self.rules, inline=False)
-
-        # Player info
         if self.blind and not dm:
             joined = len(self.players)
             plural = "s" if joined != 1 else ""
@@ -432,25 +449,17 @@ class Game(Base):
             )
         elif self.players:
             embed.add_field(name="Players", value=self.embed_players, inline=False)
-
-        # Format and Bracket
         embed.add_field(name="Format", value=self.format_name)
         if self.bracket != GameBracket.NONE.value:
             embed.add_field(name="Bracket", value=self.bracket_title)
-
-        # Timestamps
         timestamp_field = (
             ("Started at", f"<t:{self.started_at_timestamp}>")
             if self.started_at
             else ("Updated at", f"<t:{self.updated_at_timestamp}>")
         )
         embed.add_field(name=timestamp_field[0], value=timestamp_field[1])
-
-        # Service info
         if self.service != GameService.SPELLTABLE.value and not rematch:
             embed.add_field(name="Service", value=str(GameService(self.service)), inline=False)
-
-        # Embed color
         if self.players:
             embed.color = (
                 discord.Color(settings.STARTED_EMBED_COLOR)
@@ -459,12 +468,8 @@ class Game(Base):
             )
         else:
             embed.color = discord.Color(settings.EMPTY_EMBED_COLOR)
-
-        # Suggested voice channel
         if suggested_vc and (vc_xid := suggested_vc.get()):
             embed.add_field(name="🔊 Suggested Voice Channel", value=f"<#{vc_xid}>", inline=False)
-
-        # Support / footer
         embed.add_field(
             name="Support SpellBot",
             value=(
@@ -474,7 +479,6 @@ class Game(Base):
             inline=False,
         )
         embed.set_footer(text=self.embed_footer)
-
         return embed
 
     def to_dict(self) -> GameDict:
