@@ -8,11 +8,20 @@ from sqlalchemy.dialects.postgresql import insert
 from sqlalchemy.sql.expression import and_
 
 from spellbot.database import DatabaseSession
+from spellbot.environment import running_in_pytest
 from spellbot.models import Channel, Guild, GuildAward, GuildAwardDict, GuildDict
 
 if TYPE_CHECKING:
     import discord
 
+guild_cache: dict[int, str] = {}
+
+
+def is_cached(xid: int, name: str) -> bool:  # pragma: no cover
+    if running_in_pytest():
+        return False
+    return bool((cached_name := guild_cache.get(xid)) and cached_name == name)
+
 
 class GuildsService:
     guild: Guild | None = None
@@ -22,29 +31,27 @@ class GuildsService:
         name_max_len = Guild.name.property.columns[0].type.length  # type: ignore
         raw_name = getattr(guild, "name", "")
         name = raw_name[:name_max_len]
-        values = {
-            "xid": guild.id,
-            "name": name,
-            "updated_at": datetime.now(tz=UTC),
-        }
-        upsert = insert(Guild).values(**values)
-        upsert = upsert.on_conflict_do_update(
-            index_elements=[Guild.xid],
-            index_where=Guild.xid == values["xid"],
-            set_={
-                "name": upsert.excluded.name,
-                "updated_at": upsert.excluded.updated_at,
-            },
-        )
-        DatabaseSession.execute(upsert, values)
-        DatabaseSession.commit()
-        self.guild = (
-            DatabaseSession.query(Guild)
-            .filter(
-                Guild.xid == guild.id,
+        if not is_cached(guild.id, name):
+            values = {
+                "xid": guild.id,
+                "name": name,
+                "updated_at": datetime.now(tz=UTC),
+            }
+            upsert = insert(Guild).values(**values)
+            upsert = upsert.on_conflict_do_update(
+                index_elements=[Guild.xid],
+                index_where=Guild.xid == values["xid"],
+                set_={
+                    "name": upsert.excluded.name,
+                    "updated_at": upsert.excluded.updated_at,
+                },
+                where=upsert.excluded.name != Guild.name,
             )
-            .one_or_none()
-        )
+            DatabaseSession.execute(upsert, values)
+            DatabaseSession.commit()
+            guild_cache[guild.id] = name
+
+        self.guild = DatabaseSession.query(Guild).filter(Guild.xid == guild.id).one_or_none()
         return self.guild.to_dict() if self.guild else None
 
     @sync_to_async()
